==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Button/BaseButton.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.symbol.description.js';
import { FontIcon } from '../Icon/FontIcon.js';
import { Icon } from '../Icon/index.js';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import '../node_modules/core-js/modules/es.regexp.exec.js';
import '../node_modules/core-js/modules/es.string.split.js';
import { ContextualMenu } from '../ContextualMenu/ContextualMenu.js';
import '../ContextualMenu/ContextualMenu.types.js';
import { getBaseButtonClassNames } from './BaseButton.classNames.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var BaseButton = function (_BaseComponent) {
  _inherits(BaseButton, _BaseComponent);

  var _super = _createSuper(BaseButton);

  function BaseButton() {
    var _this;

    _classCallCheck(this, BaseButton);

    _this = _super.apply(this, arguments);
    _this.menuHidden = true;
    _this.menuOpen = false;
    return _this;
  }

  _createClass(BaseButton, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var ButtonComponent = this.component;
      var MenuComponent = this.MenuType;
      var classNames = this.classNames,
          href = this.href,
          iconProps = this.iconProps,
          className = this.className,
          css = this.css,
          secondaryText = this.secondaryText,
          isSplitButton = this.isSplitButton,
          menuProps = this.menuProps,
          menuIconProps = this.menuIconProps,
          shouldRenderMenu = this.shouldRenderMenu;
      return h(ButtonComponent, {
        "ref": "buttonElement",
        "class": classNames.root,
        "attrs": {
          "href": href
        }
      }, [h("span", {
        "class": classNames.flexContainer
      }, [iconProps && h(Icon, {
        "class": css(classNames.icon, className),
        "props": _objectSpread({}, iconProps)
      }), this.$scopedSlots.flex ? this.$scopedSlots.flex({}) : null, this.$scopedSlots["default"] && h("span", {
        "class": classNames.textContainer
      }, [h("span", {
        "class": classNames.label
      }, [this.$scopedSlots["default"]({})]), secondaryText && h("span", {
        "class": classNames.description
      }, [secondaryText])]), !isSplitButton && menuProps && h(FontIcon, {
        "attrs": {
          "icon-name": "ChevronDown"
        },
        "props": _objectSpread({}, menuIconProps),
        "class": classNames.menuIcon
      }), menuProps && !menuProps.doNotLayer && shouldRenderMenu && h(MenuComponent, {
        "attrs": {
          "directional-hint": DirectionalHint.bottomLeftEdge,
          "target": isSplitButton ? this.$refs.splitButtonContainer : this.$refs.buttonElement
        },
        "props": _objectSpread({}, menuProps),
        "class": css('ms-BaseButton-menuhost', menuProps.className),
        "on": {
          "dismiss": function dismiss() {
            return _this2.menuHidden = true;
          }
        }
      })])]);
    }
  }, {
    key: "MenuType",
    get: function get() {
      return this.menuAs || ContextualMenu;
    }
  }, {
    key: "component",
    get: function get() {
      var disabled = this.disabled,
          href = this.href;
      var renderAsAnchor = !disabled && !!href;
      return renderAsAnchor ? 'a' : 'button';
    }
  }, {
    key: "isSplitButton",
    get: function get() {
      return !!this.menuProps && this.split === true;
    }
  }, {
    key: "shouldRenderMenu",
    get: function get() {
      var menuHidden = this.menuHidden;
      var persistMenu = this.persistMenu,
          renderPersistedMenuHiddenOnMount = this.renderPersistedMenuHiddenOnMount;

      if (!menuHidden) {
        return true;
      } else if (persistMenu && ( renderPersistedMenuHiddenOnMount)) {
        return true;
      }

      return false;
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          iconProps = this.iconProps,
          menuIconProps = this.menuIconProps,
          variantClassName = this.variantClassName,
          disabled = this.disabled,
          primaryDisabled = this.primaryDisabled,
          checked = this.checked,
          getClassNames = this.getClassNames;
      var isPrimaryButtonDisabled = disabled || primaryDisabled;
      return getClassNames ? getClassNames(theme, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, checked, !this.menuHidden, !!this.menuProps, this.split, !!this.allowDisabledFocus) : getBaseButtonClassNames(theme, styles, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, !!this.menuProps, checked, !this.menuHidden, this.split);
    }
  }]);

  return BaseButton;
}(BaseComponent);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], BaseButton.prototype, "href", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "checked", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "split", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "primaryDisabled", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "allowDisabledFocus", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], BaseButton.prototype, "variantClassName", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], BaseButton.prototype, "iconProps", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], BaseButton.prototype, "menuIconProps", void 0);

__decorate([Prop({
  type: Object,
  "default": null
}), __metadata("design:type", Object)], BaseButton.prototype, "menuAs", void 0);

__decorate([Prop({
  type: Object,
  "default": null
}), __metadata("design:type", Object)], BaseButton.prototype, "menuProps", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "persistMenu", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "renderPersistedMenuHiddenOnMount", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], BaseButton.prototype, "secondaryText", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], BaseButton.prototype, "getClassNames", void 0);

BaseButton = __decorate([Component], BaseButton);

export { BaseButton };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Button/BaseButton.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.symbol.description';
import { FontIcon } from '../Icon/FontIcon.js';
import { Icon } from '../Icon/index.js';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import 'core-js/modules/es.regexp.exec';
import 'core-js/modules/es.string.split';
import { ContextualMenu } from '../ContextualMenu/ContextualMenu.js';
import '../ContextualMenu/ContextualMenu.types.js';
import { getBaseButtonClassNames } from './BaseButton.classNames.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var BaseButton = function (_BaseComponent) {
  _inherits(BaseButton, _BaseComponent);

  var _super = _createSuper(BaseButton);

  function BaseButton() {
    var _this;

    _classCallCheck(this, BaseButton);

    _this = _super.apply(this, arguments);
    _this.menuHidden = true;
    _this.menuOpen = false;
    return _this;
  }

  _createClass(BaseButton, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var ButtonComponent = this.component;
      var MenuComponent = this.MenuType;
      var classNames = this.classNames,
          href = this.href,
          iconProps = this.iconProps,
          className = this.className,
          css = this.css,
          secondaryText = this.secondaryText,
          isSplitButton = this.isSplitButton,
          menuProps = this.menuProps,
          menuIconProps = this.menuIconProps,
          shouldRenderMenu = this.shouldRenderMenu;
      return h(ButtonComponent, {
        "ref": "buttonElement",
        "class": classNames.root,
        "attrs": {
          "href": href
        }
      }, [h("span", {
        "class": classNames.flexContainer
      }, [iconProps && h(Icon, {
        "class": css(classNames.icon, className),
        "props": _objectSpread({}, iconProps)
      }), this.$scopedSlots.flex ? this.$scopedSlots.flex({}) : null, this.$scopedSlots.default && h("span", {
        "class": classNames.textContainer
      }, [h("span", {
        "class": classNames.label
      }, [this.$scopedSlots.default({})]), secondaryText && h("span", {
        "class": classNames.description
      }, [secondaryText])]), !isSplitButton && menuProps && h(FontIcon, {
        "attrs": {
          "icon-name": "ChevronDown"
        },
        "props": _objectSpread({}, menuIconProps),
        "class": classNames.menuIcon
      }), menuProps && !menuProps.doNotLayer && shouldRenderMenu && h(MenuComponent, {
        "attrs": {
          "directional-hint": DirectionalHint.bottomLeftEdge,
          "target": isSplitButton ? this.$refs.splitButtonContainer : this.$refs.buttonElement
        },
        "props": _objectSpread({}, menuProps),
        "class": css('ms-BaseButton-menuhost', menuProps.className),
        "on": {
          "dismiss": function dismiss() {
            return _this2.menuHidden = true;
          }
        }
      })])]);
    }
  }, {
    key: "MenuType",
    get: function get() {
      return this.menuAs || ContextualMenu;
    }
  }, {
    key: "component",
    get: function get() {
      var disabled = this.disabled,
          href = this.href;
      var renderAsAnchor = !disabled && !!href;
      return renderAsAnchor ? 'a' : 'button';
    }
  }, {
    key: "isSplitButton",
    get: function get() {
      return !!this.menuProps && this.split === true;
    }
  }, {
    key: "shouldRenderMenu",
    get: function get() {
      var menuHidden = this.menuHidden;
      var persistMenu = this.persistMenu,
          renderPersistedMenuHiddenOnMount = this.renderPersistedMenuHiddenOnMount;

      if (!menuHidden) {
        return true;
      } else if (persistMenu && ( renderPersistedMenuHiddenOnMount)) {
        return true;
      }

      return false;
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          iconProps = this.iconProps,
          menuIconProps = this.menuIconProps,
          variantClassName = this.variantClassName,
          disabled = this.disabled,
          primaryDisabled = this.primaryDisabled,
          checked = this.checked,
          getClassNames = this.getClassNames;
      var isPrimaryButtonDisabled = disabled || primaryDisabled;
      return getClassNames ? getClassNames(theme, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, checked, !this.menuHidden, !!this.menuProps, this.split, !!this.allowDisabledFocus) : getBaseButtonClassNames(theme, styles, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, !!this.menuProps, checked, !this.menuHidden, this.split);
    }
  }]);

  return BaseButton;
}(BaseComponent);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], BaseButton.prototype, "href", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "checked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "split", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "primaryDisabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "allowDisabledFocus", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], BaseButton.prototype, "variantClassName", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], BaseButton.prototype, "iconProps", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], BaseButton.prototype, "menuIconProps", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], BaseButton.prototype, "menuAs", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], BaseButton.prototype, "menuProps", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "persistMenu", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], BaseButton.prototype, "renderPersistedMenuHiddenOnMount", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], BaseButton.prototype, "secondaryText", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], BaseButton.prototype, "getClassNames", void 0);

BaseButton = __decorate([Component], BaseButton);

export { BaseButton };
